@@ -11,6 +11,7 @@ use Params::Validate qw(:types);
 __PACKAGE__->valid_params
   (
    categories => { type => ARRAYREF|HASHREF },
+   sig_figs   => { type => SCALAR, default => 4 },
   );
 
 sub new {
@@ -33,6 +34,11 @@ sub add_hypothesis {
   $self->add_result([$h->categories], $correct, $name);
 }
 
+sub stats_table {
+  my $self = shift;
+  $self->SUPER::stats_table($self->{sig_figs});
+}
+
 1;
 
 __END__
@@ -49,7 +55,7 @@ AI::Categorizer::Experiment - Coordinate experimental results
  
  while (my $d = ... get document ...) {
    my $h = $l->categorize($d); # A Hypothesis
-   $e->add_hypothesis($h, [$d->categories]);
+   $e->add_hypothesis($h, [map $_->name, $d->categories]);
  }
  
  print "Micro F1: ", $e->micro_F1, "\n"; # Access a single statistic
@@ -80,17 +86,27 @@ its methods are available here, with the following additions:
 
 =item new( categories => \%categories )
 
-=item new( categories => \@categories, verbose => 1 )
+=item new( categories => \@categories, verbose => 1, sig_figs => 2 )
 
 Returns a new Experiment object.  A required C<categories> parameter
 specifies the names of all categories in the data set.  The category
 names may be specified either the keys in a reference to a hash, or as
 the entries in a reference to an array.
 
-In addition, the C<new()> method accepts a C<verbose> parameter which
+The C<new()> method accepts a C<verbose> parameter which
 will cause some status/debugging information to be printed to
 C<STDOUT> when C<verbose> is set to a true value.
 
+A C<sig_figs> indicates the number of significant figures that should
+be used when showing the results in the C<results_table()> method.  It
+does not affect the other methods like C<micro_precision()>.
+
+=item add_result($assigned, $correct, $name)
+
+Adds a new result to the experiment.  Please see the
+C<Statistics::Contingency> documentation for a description of this
+method.
+
 =item add_hypothesis($hypothesis, $correct_categories)
 
 Adds a new result to the experiment.  The first argument is a
@@ -98,13 +114,18 @@ C<AI::Categorizer::Hypothesis> object such as one generated by a
 Learner's C<categorize()> method.  The list of correct categories can
 be given as an array of category names (strings), as a hash whose keys
 are the category names and whose values are anything logically true,
-or as a single string if there is only one category.
+or as a single string if there is only one category.  For example, all
+of the following are legal:
+
+ $e->add_hypothesis($h, "sports");
+ $e->add_hypothesis($h, ["sports", "finance"]);
+ $e->add_hypothesis($h, {sports => 1, finance => 1});
 
 =back
 
 =head1 AUTHOR
 
-Ken Williams <kenw@ee.usyd.edu.au>
+Ken Williams <ken@mathforum.org>
 
 =head1 COPYRIGHT
 
